==> apache-iotdb-1.3.3-source-release.zip: apache-iotdb-1.3.3/iotdb-client/session/src/main/java/org/apache/iotdb/session/subscription/payload/SubscriptionSessionDataSetsHandler.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.apache.iotdb.session.subscription.payload;

import org.apache.iotdb.rpc.subscription.exception.SubscriptionIncompatibleHandlerException;

import org.apache.tsfile.write.record.Tablet;

import java.util.ArrayList;
import java.util.Iterator;
import java.util.List;

public class SubscriptionSessionDataSetsHandler
    implements Iterable<SubscriptionSessionDataSet>, SubscriptionMessageHandler {

  private final List<SubscriptionSessionDataSet> dataSets;

  private final List<Tablet> tablets;

  public SubscriptionSessionDataSetsHandler(final List<Tablet> tablets) {
    this.dataSets = new ArrayList<>();
    this.tablets = tablets;
    tablets.forEach((tablet -> this.dataSets.add(new SubscriptionSessionDataSet(tablet))));
  }

  @Override
  public Iterator<SubscriptionSessionDataSet> iterator() {
    return dataSets.iterator();
  }

  public Iterator<Tablet> tabletIterator() {
    return tablets.iterator();
  }

  @Override
  public SubscriptionSessionDataSetsHandler getSessionDataSetsHandler() {
    return this;
  }

  @Override
  public SubscriptionTsFileHandler getTsFileHandler() {
    throw new SubscriptionIncompatibleHandlerException(
        "SubscriptionSessionDataSetsHandler do not support getSessionDataSetsHandler().");
  }
}

==> apache-iotdb-1.3.6-source-release.zip: apache-iotdb-1.3.6/iotdb-client/session/src/main/java/org/apache/iotdb/session/subscription/payload/SubscriptionSessionDataSetsHandler.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.apache.iotdb.session.subscription.payload;

import org.apache.iotdb.rpc.subscription.exception.SubscriptionIncompatibleHandlerException;

import org.apache.tsfile.write.record.Tablet;

import java.util.Iterator;
import java.util.List;

public class SubscriptionSessionDataSetsHandler
    implements Iterable<SubscriptionSessionDataSet>, SubscriptionMessageHandler {

  private final List<Tablet> tablets;

  public SubscriptionSessionDataSetsHandler(final List<Tablet> tablets) {
    this.tablets = tablets;
  }

  @Override
  public Iterator<SubscriptionSessionDataSet> iterator() {
    return new Iterator<SubscriptionSessionDataSet>() {
      final Iterator<Tablet> tabletsIterator = tablets.iterator();

      @Override
      public boolean hasNext() {
        return tabletsIterator.hasNext();
      }

      @Override
      public SubscriptionSessionDataSet next() {
        return new SubscriptionSessionDataSet(tabletsIterator.next());
      }
    };
  }

  public Iterator<Tablet> tabletIterator() {
    return tablets.iterator();
  }

  @Override
  public SubscriptionSessionDataSetsHandler getSessionDataSetsHandler() {
    return this;
  }

  @Override
  public SubscriptionTsFileHandler getTsFileHandler() {
    throw new SubscriptionIncompatibleHandlerException(
        "SubscriptionSessionDataSetsHandler do not support getSessionDataSetsHandler().");
  }
}
